@@ -32,6 +32,15 @@ splitGroup pred x =
       else if null (snd z) then Just (fst z, [])
          else Just (fst z, tail (snd z))
 
+-- | splits a list into pieces separated with an
+-- element satisfying a predicate, drops the separator
+splitWithDrop :: (a -> Bool)-> [a] ->[[a]]
+splitWithDrop p = unfoldr (split_once p)
+   where
+      split_once _ [] = Nothing
+      split_once p x@(h:t) = if p h then Just$ break p (drop 1 x)
+                             else Just $ break p x
+
 
 --checks if a string is prefixed by any from a list of prefixes
 -- best used infix
@@ -47,10 +56,6 @@ breakAtDrop :: (a -> Bool) -> [a] -> ([a], [a])
 breakAtDrop pred x = (fst y, tail (snd y) ) 
    where y = break pred x 
 
--- do I really have to define this?
--- isADigit :: Char -> Bool
--- isADigit c = any (c==) ['0','1','2','3','4','5','6','7','8','9']
-
 -- for readibility
 sndEl :: [a] -> a
 sndEl x = (!!) x 1
@@ -116,3 +121,15 @@ snd3 (n,k,l) = k
 -- for extracting the third element of a triple
 thrd3 :: (a,b,c) -> c
 thrd3 (n,k,l) = l
+
+-- | converts a 3 element list into a triple
+ls2triple :: [a] -> (a,a,a)
+ls2triple x = if (length x) /= 3 then error ( "s2triple: can not convert a list of length " ++ (show $ length x) )
+              else (a,b,c)
+                 where
+                 a = head x
+                 b = x!!1
+                 c = x!!2
+
+
+
